import { DEFAULT_BASE_URL } from './initializeFileTypeIcons';
import { getFileTypeIconNameFromExtensionOrType, getFileTypeIconSuffix, DEFAULT_ICON_SIZE, } from './getFileTypeIconProps';
/**
 * Given the `fileTypeIconOptions`, this function returns the CDN-based URL for `FileTypeIcon`.
 * Similar to `getFileTypeIconProps`, this also accepts the same type of object
 * but rather than returning the `iconName`, this returns the raw URL.
 * @param options
 * @param baseUrl - optionally provide a custom CDN base url to fetch icons from
 */
export function getFileTypeIconAsUrl(options, baseUrl) {
    if (baseUrl === void 0) { baseUrl = DEFAULT_BASE_URL; }
    var extension = options.extension, _a = options.size, size = _a === void 0 ? DEFAULT_ICON_SIZE : _a, type = options.type, imageFileType = options.imageFileType;
    var baseIconName = getFileTypeIconNameFromExtensionOrType(extension, type); // eg: docx
    var baseSuffix = getFileTypeIconSuffix(size, imageFileType); // eg: 96_3x_svg or 96_png
    var suffixArray = baseSuffix.split('_'); // eg: ['96', '3x', 'svg']
    if (suffixArray.length === 3) {
        /** suffix is of type 96_3x_svg  - it has a pixel ratio > 1*/
        return "".concat(baseUrl).concat(size, "_").concat(suffixArray[1], "/").concat(baseIconName, ".").concat(suffixArray[2]);
    }
    else if (suffixArray.length === 2) {
        /** suffix is of type 96_svg  - it has a pixel ratio of 1*/
        return "".concat(baseUrl).concat(size, "/").concat(baseIconName, ".").concat(suffixArray[1]);
    }
}
//# sourceMappingURL=getFileTypeIconAsUrl.js.map